# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_anticipation_limits_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.get_anticipation_limit_response

class GetAnticipationLimitsResponse(object):

    """Implementation of the 'GetAnticipationLimitsResponse' model.

    Anticipation limits

    Attributes:
        max (GetAnticipationLimitResponse): Max limit
        min (GetAnticipationLimitResponse): Min limit

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "max":'max',
        "min":'min'
    }

    def __init__(self,
                 max=None,
                 min=None):
        """Constructor for the GetAnticipationLimitsResponse class"""

        # Initialize members of the class
        self.max = max
        self.min = min


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        max = mundiapi.models.get_anticipation_limit_response.GetAnticipationLimitResponse.from_dictionary(dictionary.get('max')) if dictionary.get('max') else None
        min = mundiapi.models.get_anticipation_limit_response.GetAnticipationLimitResponse.from_dictionary(dictionary.get('min')) if dictionary.get('min') else None

        # Return an object of this model
        return cls(max,
                   min)


